==> flask_ml-0.2.4.tar.gz: flask_ml-0.2.4/website/materials/guides/examples.md <==
---
sidebar_position: 3
---

# Example ML Projects

Here's a list of ML projects along with their Github links.

| Project                                                                                                                                       | Description                                                              |
| --------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------ |
| [Audio Named Entity Recognition](https://github.com/atharvakale343/AudioNER) <br/> by [anjus1313](https://github.com/anjus1313)        | Transcribe audio files and find named entities within them.              |
| [TTS Text-to-Speech](https://github.com/sahithi-66/TTS-Flask-ML) <br/> by [sahithi-66](https://github.com/sahithi-66)                         | Converts a collection of text inputs to audio files.                     |
| [Image Object Detection](https://github.com/Shreneken/image_object_detection) <br/> by [Shreneken](https://github.com/Shreneken)              | Detects 80 common objects in an image and produces bounding boxes        |
| [Image Super Resolution](https://github.com/ShriramG24/IMG-Super-Resolution) <br/> by [ShriramG24](https://github.com/ShriramG24)             | Upscales an image to a higher resolution.                                |
| [Small Block Forensics](https://github.com/atharvakale343/small-block-forensics) <br/> by [atharvakale343](https://github.com/atharvakale343) | A forensic technique to search for a subset of files in a large dataset. |
| [Audio Transcription](https://github.com/prasannals/audio-transcription) <br/> by [prasannals](https://github.com/prasannals)                 | Transforms a batch of audio files to their transcriptions.               |

==> flask_ml-0.2.5.tar.gz: flask_ml-0.2.5/website/materials/guides/examples.md <==
---
sidebar_position: 3
---

# Example ML Projects

Here's a list of ML projects along with their Github links.

| Project                                                                                                                                       | Description                                                              |
| --------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------ |
| [Audio Named Entity Recognition](https://github.com/atharvakale343/AudioNER) <br/> by [anjus1313](https://github.com/anjus1313)        | Transcribe audio files and find named entities within them.              |
| [TTS Text-to-Speech](https://github.com/ShriramG24/TTS-Flask-ML) <br/> by [sahithi-66](https://github.com/sahithi-66)                         | Converts a collection of text inputs to audio files.                     |
| [Image Object Detection](https://github.com/Shreneken/image_object_detection) <br/> by [Shreneken](https://github.com/Shreneken)              | Detects 80 common objects in an image and produces bounding boxes        |
| [Image Super Resolution](https://github.com/ShriramG24/IMG-Super-Resolution) <br/> by [ShriramG24](https://github.com/ShriramG24)             | Upscales an image to a higher resolution.                                |
| [Small Block Forensics](https://github.com/atharvakale343/small-block-forensics) <br/> by [atharvakale343](https://github.com/atharvakale343) | A forensic technique to search for a subset of files in a large dataset. |
| [Audio Transcription](https://github.com/prasannals/audio-transcription) <br/> by [prasannals](https://github.com/prasannals)                 | Transforms a batch of audio files to their transcriptions.               |
